@@ -392,10 +392,10 @@ class Functions:
                         break
                     for _allow in _allowed:
                         if isinstance(giterator, str) and '/' in giterator:
-                            _allowed_wdays.update({d for d in week[_allow::int(giterator[1:])] if d > 0})
+                            _allowed_wdays.update({d for d in week[_allow % 7::int(giterator[1:])] if d > 0})
                         else:
-                            if week[_allow] != 0:
-                                _allowed_wdays.add(week[_allow])
+                            if week[_allow % 7] != 0:
+                                _allowed_wdays.add(week[_allow % 7])
                                 if isinstance(giterator, str) and 'L' in giterator:
                                     # Если мы нашли нужный день, дальше итерироваться не стоит
                                     break
